Enum genco::java::Java
[−]
[src]
pub enum Java<'el> {
Primitive {
boxed: &'static str,
primitive: &'static str,
},
Class(Type<'el>),
Local {
name: Cons<'el>,
},
Optional(Optional<'el>),
}Java token specialization.
Variants
PrimitivePrimitive type.
Fields of Primitive
boxed: &'static str | The boxed variant of the primitive type. |
primitive: &'static str | The primitive-primitive type. |
Class(Type<'el>)A class, with or without arguments, imported from somewhere.
LocalA local name with no specific qualification.
Fields of Local
name: Cons<'el> | Name of class. |
Optional(Optional<'el>)Optional type.
Methods
impl<'el> Java<'el>[src]
pub fn path<P: Into<Cons<'el>>>(&self, part: P) -> Java<'el>[src]
Extend the type with a nested path.
This discards any arguments associated with it.
pub fn with_arguments(&self, arguments: Vec<Java<'el>>) -> Java<'el>[src]
Add arguments to the given variable.
Only applies to classes, any other will return the same value.
pub fn as_raw(&self) -> Java<'el>[src]
Get the raw type.
A raw type is one without generic arguments.
pub fn as_boxed(&self) -> Java<'el>[src]
Get a guaranteed boxed version of a type.
pub fn equals(&self, other: &Java<'el>) -> bool[src]
Compare if two types are equal.
pub fn name(&self) -> Cons<'el>[src]
Get the name of the type.
pub fn package(&self) -> Option<Cons<'el>>[src]
Get the name of the type.
pub fn arguments(&self) -> Option<&[Java<'el>]>[src]
Get the arguments
pub fn is_optional(&self) -> bool[src]
Check if type is optional.
pub fn is_primitive(&self) -> bool[src]
Check if variable is primitive.
pub fn as_optional(&self) -> Option<&Optional<'el>>[src]
Get type as optional.
pub fn as_field(&self) -> Java<'el>[src]
Get the field type (includes optionality).
pub fn as_value(&self) -> Java<'el>[src]
Get the value type (strips optionality).